@@ -20,6 +20,7 @@
 #include <QActionGroup>
 
 // KF
+#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -326,7 +327,7 @@ void Editor::newBoard()
 bool Editor::saveBoard()
 {
     if (!((m_numTiles != 0) && ((m_numTiles & 1) == 0))) {
-        KMessageBox::sorry(this, i18n("You can only save with a even number of tiles."));
+        KMessageBox::error(this, i18n("You can only save with a even number of tiles."));
 
         return false;
     }
@@ -371,16 +372,24 @@ bool Editor::testSave()
         return true;
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int res = KMessageBox::warningTwoActionsCancel(this,
+#else
     const int res = KMessageBox::warningYesNoCancel(this,
+#endif
                                                     i18n("The board has been modified. Would you like to save the changes?"),
                                                     QString(), KStandardGuiItem::save(), KStandardGuiItem::dontSave());
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (res == KMessageBox::PrimaryAction) {
+#else
     if (res == KMessageBox::Yes) {
+#endif
         // yes to save
         if (saveBoard()) {
             return true;
         } else {
-            KMessageBox::sorry(this, i18n("Save failed. Aborting operation."));
+            KMessageBox::error(this, i18n("Save failed. Aborting operation."));
 
             return false;
         }
