@@ -25,6 +25,7 @@
 #include <QRandomGenerator>
 
 // KF
+#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigDialog>
 #include <KLocalizedString>
@@ -398,15 +399,27 @@ void KMahjongg::noMovesAvailable()
 
     const QIcon newGameIcon = actionCollection()->action(QString::fromLatin1(KStandardGameAction::name(KStandardGameAction::New)))->icon();
     const QIcon restartIcon = actionCollection()->action(QString::fromLatin1(KStandardGameAction::name(KStandardGameAction::Restart)))->icon();
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    int answer = KMessageBox::questionTwoActionsCancel(
+#else
     int answer = KMessageBox::questionYesNoCancel(
+#endif
         this,
         i18n("Game Over: You have no moves left."),
         i18n("Game Over"),
         KGuiItem(i18n("New Game"), newGameIcon),
         KGuiItem(i18n("Restart"), restartIcon));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (answer == KMessageBox::PrimaryAction) {
+#else
     if (answer == KMessageBox::Yes) {
+#endif
         startNewGame();
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    } else if (answer == KMessageBox::SecondaryAction) {
+#else
     } else if (answer == KMessageBox::No) {
+#endif
         restartGame();
     }
 }
@@ -625,7 +638,7 @@ void KMahjongg::loadGame()
     QFile infile(filename);
 
     if (!infile.open(QFile::ReadOnly)) {
-        KMessageBox::sorry(this, i18n("Could not read from file. Aborting."));
+        KMessageBox::error(this, i18n("Could not read from file. Aborting."));
         return;
     }
 
@@ -636,7 +649,7 @@ void KMahjongg::loadGame()
     in >> magic;
 
     if (QString::compare(magic, gameMagic(), Qt::CaseSensitive) != 0) {
-        KMessageBox::sorry(this, i18n("File is not a KMahjongg game."));
+        KMessageBox::error(this, i18n("File is not a KMahjongg game."));
         infile.close();
 
         return;
@@ -649,7 +662,7 @@ void KMahjongg::loadGame()
     if (version == gameDataVersion) {
         in.setVersion(QDataStream::Qt_4_0);
     } else {
-        KMessageBox::sorry(this, i18n("File format not recognized."));
+        KMessageBox::error(this, i18n("File format not recognized."));
         infile.close();
         return;
     }
@@ -701,7 +714,7 @@ void KMahjongg::saveGame()
     QFile outfile(filename);
 
     if (!outfile.open(QFile::WriteOnly)) {
-        KMessageBox::sorry(this, i18n("Could not open file for saving."));
+        KMessageBox::error(this, i18n("Could not open file for saving."));
         m_gameTimer->resume();
         return;
     }
@@ -736,15 +749,27 @@ void KMahjongg::saveGame()
 
 bool KMahjongg::askSaveGame()
 {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const KMessageBox::ButtonCode ret = KMessageBox::questionTwoActionsCancel(this,
+#else
     const KMessageBox::ButtonCode ret = KMessageBox::questionYesNoCancel(this, 
+#endif
             i18n("Do you want to save your game?"), i18n("Save game?"), KStandardGuiItem::save(), 
             KStandardGuiItem::dontSave(), KStandardGuiItem::cancel());
 
     switch (ret) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::PrimaryAction:
+#else
     case KMessageBox::ButtonCode::Yes:
+#endif
         saveGame();
         break;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::SecondaryAction:
+#else
     case KMessageBox::ButtonCode::No:
+#endif
         break;
     case KMessageBox::ButtonCode::Cancel:
         return false;
